# Features

There is a lot that goes into defining what a definition means.  Is it just the set of words that conveys the 
same idea different?  Does it include different forms of expression (i.e. Pronounciation [audio] vs. text vs.
Images [visual])?  Synonyms? Examples?  I'm sure there's a language standard for what a definition entails.

For the sake of continuous development and improvement, the following matrix outlines the supported definition
attributes of each lookup method

| Definition                |       Google Search     |    Wiktionary Search    |
| ------------------------- | ----------------------- | ----------------------- |
| Classic Definition        | :ballot_box_with_check: | :ballot_box_with_check: |
| Pronounciation (Phonetics)| :ballot_box_with_check: | :ballot_box_with_check: |
| Pronounciation (Audio)    | :white_square_button: :mailbox_with_no_mail:   | :white_square_button: :mailbox_with_no_mail:   |
| Part of Speech            | :ballot_box_with_check: | :ballot_box_with_check: |
| Synonyms                  | :ballot_box_with_check: | :white_square_button: :mailbox_with_no_mail:   |
| Antonyms                  | :white_square_button: :mailbox_with_no_mail:   | :white_square_button: :mailbox_with_no_mail:   |
| Examples                  | :ballot_box_with_check: | :white_square_button: :mailbox_with_no_mail:   |
| Lemmas                    | :white_square_button: :mailbox_with_no_mail:   | :white_square_button: :mailbox_with_no_mail:   |
| Etymology                 | :white_square_button: :mailbox_with_no_mail:   | :white_square_button: :mailbox_with_no_mail:   |
